Crate wrpc_runtime_wasmtime

Structs

RemoteResource
SharedResourceTable
A table of shared resources exported by the component
ValEncoder

Traits

ServeExt
WrpcView

Functions

call
collect_component_resources
Recursively iterates the component type and collects all exported resource types
collect_instance_resources
Recursively iterates the component type and collects all exported resource types
collect_item_resources
Recursively iterates the component item type and collects all exported resource types
link_function
Polyfill types::ComponentFunc in a LinkerInstance using wrpc_transport::Invoke
link_instance
Polyfill types::ComponentInstance in a LinkerInstance using wrpc_transport::Invoke
link_item
Polyfill types::ComponentItem in a LinkerInstance using wrpc_transport::Invoke
read_value
Read encoded value of type Type from an AsyncRead into a Val